#!/usr/bin/python -ttE

import datetime
import glob
import os
import subprocess
import sys

import ss_convert


def process_dir(dirname):
	dirname = os.path.normpath(dirname)

	if ( not os.path.isdir(dirname) ):
		sys.stderr.write('Skipping %s: Not a directory\n' % (dirname,))
		return

	tga_screenshots = glob.glob(os.path.join(dirname, 'sof[0-9][0-9].tga'))
	for tga_screenshot in tga_screenshots:
		sys.stdout.write('Converting %s\n' % (tga_screenshot,))

		# Get timestamp info
		mtime = os.path.getmtime(tga_screenshot)
		timestamp_meta = datetime.datetime.utcfromtimestamp(mtime).strftime('%Y-%m-%dT%H:%M:%S.%f+00:00')
		timestamp_name = datetime.datetime.utcfromtimestamp(mtime).strftime('%Y-%m-%d_%H%M%S')

		# Create new filename
		png_screenshot = os.path.join(dirname, ''.join(['sof_', timestamp_name, '.png']))
		counter = 1
		while os.path.exists(png_screenshot):
			counter = counter + 1
			png_screenshot = os.path.join(dirname, ''.join(['sof_', timestamp_name, '_', str(counter), '.png']))

		# Convert .tga to .png
		child = subprocess.Popen(
		                          [
		                            ss_convert.IM_CONVERT,
		                            tga_screenshot,
		                            '-set',
		                            'ssts',
		                            timestamp_meta,
		                            png_screenshot
		                          ]
		                        )
		child.wait()
		if (
		     ( child.returncode == 0 ) and
		     ( os.path.isfile(png_screenshot) ) and
		     ( os.path.getsize(png_screenshot) > 0 )
		   ):
			os.utime(png_screenshot, (mtime, mtime))
			os.remove(tga_screenshot)

			# Convert to different formats
			ss_convert.convert(png_screenshot)
		else:
			sys.stderr.write('Conversion of %s to %s failed\n' % (tga_screenshot, png_screenshot))


if __name__ == '__main__':
	if ( len(sys.argv) > 1 ):
		# Process specified directories
		for dirname in sys.argv[1:]:
			process_dir(dirname)
	else:
		# Process current directory
		process_dir('.')
